# Subtract numbers module

class Calculate:

	def sub(a, b):
		"""Substract two numbers"""
		return a - b

	def add(a, b):
		"""Add two numbers"""
		return a + b

	def mult(a, b):
		"""Product of two numbers"""
		return a * b

	def div(a, b):
		"""Divide two numbers"""
		return a / b
